@@ -3,6 +3,8 @@ import inspect
 
 from pywebvue import App
 
+__version__ = "1.3.0"
+
 NEXT_TRIGGER_ID = 0
 TRIGGER_MAP = {}
 NEXT_APP_ID = 0
@@ -131,21 +133,26 @@ def start(layout=None, name=None, favicon=None, on_ready=None, port=None):
     if name:
         app.name = name
 
-    if favicon:
-        app.favicon = os.path.join(base_directory(), favicon)
-
     if layout:
         if isinstance(layout, str):
             app.layout = layout
         else:
             app.name = layout.name
             app.layout = layout.html
+            if layout.favicon:
+                app.favicon = layout.favicon
+            if layout.on_ready:
+                app.on_ready = layout.on_ready
     else:
         tpl_path = os.path.join(base_directory(), "template.html")
         if os.path.exists(tpl_path):
             app.layout = tpl_path
 
-    app.on_ready = on_ready
+    if on_ready:
+        app.on_ready = on_ready
+
+    if favicon:
+        app.favicon = os.path.join(base_directory(), favicon)
 
     # Dev validation
     validate_key_names()
@@ -207,7 +214,54 @@ def update_layout(layout):
 def enable_module(module):
     """Load module"""
     _app = get_app_instance()
-    _app.enableModule(module)
+    _app.enable_module(module)
+
+
+def js_call(ref=None, method=None, args=[]):
+    """Python call method on JS element"""
+    _app = get_app_instance()
+    _app.update(ref=ref, method=method, args=args)
+
+
+def js_property(ref=None, property=None, value=None):
+    """Python update property on JS element"""
+    _app = get_app_instance()
+    _app.update(ref=ref, property=property, value=value)
+
+
+# -----------------------------------------------------------------------------
+# App CLI handling
+# -----------------------------------------------------------------------------
+
+
+def get_cli_parser():
+    """Run or add to argparse parser"""
+    _app = get_app_instance()
+    return _app.cli_parser
+
+
+def get_cli_args():
+    """Return parsed args"""
+    _app = get_app_instance()
+    return _app.cli_args
+
+
+def flush_state(*args):
+    """Flush dirty state"""
+    _app = get_app_instance()
+    return _app.flush_state(*args)
+
+
+def is_dirty(*args):
+    """See which key in an @change has been modified"""
+    _app = get_app_instance()
+    return _app.is_dirty(*args)
+
+
+def is_dirty_all(*args):
+    """See whether all keys in an @change have been modified"""
+    _app = get_app_instance()
+    return _app.is_dirty_all(*args)
 
 
 # -----------------------------------------------------------------------------
