@@ -13,6 +13,25 @@ def py2js_key(key):
     return key.replace("_", "-")
 
 
+class ElementContextManager:
+    def __init__(self):
+        self.element_stack = []
+
+    def enter(self, elem):
+        self.element_stack.append(elem)
+
+    def exit(self, elem):
+        if len(self.element_stack) and elem == self.element_stack[-1]:
+            self.element_stack.pop()
+
+    def add_child(self, elem):
+        if len(self.element_stack):
+            self.element_stack[-1].add_child(elem)
+
+
+HTML_CTX = ElementContextManager()
+
+
 class AbstractElement:
     _next_id = 1
 
@@ -53,7 +72,10 @@ class AbstractElement:
             "v_for",
             ("key", ":key"),
         ]
-        self._event_names += ["click", "mousedown", "mouseup"]
+        self._event_names += ["click", "mousedown", "mouseup", "contextmenu"]
+
+        # Add ourself to context is any
+        HTML_CTX.add_child(self)
 
     def _attr_str(self):
         return " ".join(self._attributes.values())
@@ -91,6 +113,8 @@ class AbstractElement:
             self.__dict__[name] = value
         elif name == "content":
             self._txt = value
+        elif name == "children":
+            self._children = value
         elif name in self._allowed_keys:
             self._py_attr[name] = value
         else:
@@ -190,6 +214,19 @@ class AbstractElement:
                     )
         return self
 
+    def clear(self):
+        self._txt = None
+        self._children.clear()
+
+    def hide(self):
+        self._attributes["__style"] = 'style="display: none"'
+
+    def add_child(self, child):
+        self._children.append(child)
+
+    def add_children(self, children):
+        self._children += children
+
     @property
     def content(self):
         return self._txt
@@ -222,6 +259,17 @@ class AbstractElement:
         else:
             return f"<{self._elem_name} {self._attr_str()} />"
 
+    # -------------------------------------------------------------------------
+    # Resource manager
+    # -------------------------------------------------------------------------
+
+    def __enter__(self):
+        HTML_CTX.enter(self)
+        return self
+
+    def __exit__(self, exc_type, exc_value, exc_traceback):
+        HTML_CTX.exit(self)
+
 
 class Element(AbstractElement):
     def __init__(self, __elem_name, __content=None, **kwargs):
@@ -236,3 +284,66 @@ class Div(AbstractElement):
 class Span(AbstractElement):
     def __init__(self, __content=None, **kwargs):
         super().__init__("span", __content, **kwargs)
+
+
+class Form(AbstractElement):
+    def __init__(self, __content=None, **kwargs):
+        super().__init__("form", __content, **kwargs)
+        self._attr_names += ["action"]
+
+
+class Label(AbstractElement):
+    def __init__(self, __content=None, **kwargs):
+        super().__init__("label", __content, **kwargs)
+
+
+class Input(AbstractElement):
+    def __init__(self, __content=None, **kwargs):
+        super().__init__("input", __content, **kwargs)
+        self._attr_names += [
+            "type",
+            "value",
+            "name",
+            "size",
+            "min",
+            "max",
+            "step",
+            "maxlength",
+            "disabled",
+            "readonly",
+            "multiple",
+            "pattern",
+            "placeholder",
+            "required",
+            "autofocus",
+            "src",
+            "width",
+            "height",
+            "alt",
+            "list",
+            "autocomplete",
+        ]
+
+
+class Template(AbstractElement):
+    slot_names = set()
+
+    def __init__(self, __content=None, **kwargs):
+        super().__init__("template", __content, **kwargs)
+        self._attr_names += ["v_slot"]
+        for slot_name in Template.slot_names:
+            safe_name = slot_name.replace("-", "_").replace(".", "_")
+            if "<name>" in safe_name:
+                safe_header, safe_tail = safe_name.split("<name>")
+                header, tail = slot_name.split("<name>")
+                for key in kwargs:
+                    if key.startswith(header):
+                        dyna_name = key[len(header) : -len(tail)]
+                        self._attr_names.append(
+                            (
+                                f"v_slot_{safe_header}{dyna_name}{safe_tail}",
+                                f"v-slot:{header}{dyna_name}{tail}",
+                            )
+                        )
+            else:
+                self._attr_names.append((f"v_slot_{safe_name}", f"v-slot:{slot_name}"))
